// Competing risks example


clear all
set scheme fpsaus_c
global dofile competing_risks_example.do


use http://www.pclambert.net/data/rott3, clear 

table cause, statistic(frequency) statistic(percent)

// death due to cancer
stset os, failure(cause=1) exit(time 120) scale(12) 
stpm3 @ns(age, df(5)) i.size i.grade pr_1 @fn(exp(-0.12 * nodes),stub(enodes)), ///
   scale(lnodds) df(3) 
estimates store cancer

// death due to other causes
stset os, failure(cause=2) exit(time 120) scale(12) 
stpm3 @ns(age,df(3)), scale(lncumhazard) df(3) 
estimates store other

range tt 0 10 101 
// Conditional predictions
predict cif50 cif60 cif70, cif crmodels(cancer other) ci             ///
                           timevar(0 10, step(0.1))                   ///
                           at1(age 50 size 1 grade 2 nodes 3 pr_1 0) ///
                           at2(age 60 size 1 grade 2 nodes 3 pr_1 0) ///             
                           at3(age 70 size 1 grade 2 nodes 3 pr_1 0) ///
                           frame(cifs, replace)
                           
// Marginal predictions
standsurv CIF_size1 CIF_size3, cif crmodels(cancer other) ci         ///
                           timevar(tt)                              ///
                           at1(size 1)                               ///
                           at2(size 3)                               ///
                           contrast(difference) contrastvar(cifdiff) ///
                           frame(cifstand, replace)                            
                 text(cif crmodels(cancer other))
                           
                           
predict F50 F60 F70, failure ci crmodels(cancer other)               ///
                           at1(age 50 size 1 grade 2 nodes 3 pr_1 0) ///
                           at2(age 60 size 1 grade 2 nodes 3 pr_1 0) ///             
                           at3(age 70 size 1 grade 2 nodes 3 pr_1 0) ///                     
                           frame(cifs, merge)
 
frame cifs {
  twoway (line cif??_cancer tt)                                                 ///
         (line  cif??_other tt, pstyle(p1line p2line p3line) lpattern(dash..)), ///
         xtitle("Years since surgery")                                          ///
         ytitle("CIF(t)")                                                       ///
         ylabel(0(0.1)0.6,format(%3.2f))                                        ///
         legend(order(1 "Age 50" 2 "Age 60" 3 "Age 70")                         ///
                pos(11))                                                        ///
         caption("Death due to cancer (solid) and other causes (dashed)", size(*0.4))          ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))       ///
         name(age, replace)
         
  twoway (rarea cif50_cancer F50 tt, color(%30))     ///
         (area cif50_cancer tt, color(%30)),         ///
         xtitle("Years since surgery")               ///
         ytitle("CIF(t)")                            ///
         ylabel(0(0.1)0.6,format(%3.2f))             ///
         title("Age 50")                             ///         
         legend(order(2 "Death due to cancer"        ///
                      1 "Death due to other causes") ///
                      pos(11))                       ///
         name(cif50, replace)
         
  twoway (rarea cif70_cancer F70 tt, color(%30))     ///
         (area cif70_cancer tt, color(%30)),         ///
         xtitle("Years since surgery")               ///
         ytitle("CIF(t)")                            ///
         ylabel(0(0.1)0.6,format(%3.2f))             ///
         title("Age 70")                             ///
         legend(order(2 "Death due to cancer"        ///
                      1 "Death due to other causes") ///
                      pos(11))                       ///
         name(cif70, replace)
  graph combine cif50 cif70, nocopies                                    ///
        note("Graph code in ${dofile}", size(vsmall) span color(gs3%50)) 

         
} 
 
recode age (min/35=1) (35/50=2) (50/60=3) (60/70=4) (70/max=5), gen(agegrp)
label define agelab 1 "<35" 2 "35-50" 3 "50-60" 4 "60-70" 5 "70+"
label values agegrp agelab
label variable agegrp "Age Group"
 
stset os, failure(cause=1) exit(time 120) scale(12) 
stpm3aj i.agegrp , crmodels(cancer other) compet1(2) 
                 text(crmodels(cancer other) compet1(2))

                 
graph combine cancer other, nocopies ycommon ///
      note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

