// This file calculates the attributable fraction
// Paul Lambert 2024-08-31

clear all
set scheme fpsaus_c
global dofile standsurv_PAF.do

use rott3

// Fit model
stpm3 i.hormon age enodes pr_1, scale(lncumhazard) df(4) eform nolog 


// marginal estimates
range tt 0 10 101
standsurv,  failure timevar(tt) ci frame(AF1, replace)  /// 
            at1(hormon 0) at2(hormon 1) at3(.)          ///
            atvar(F_hormon0 F_hormon1 F_all)
            
// Note hormon=1 is "unexposed"            
frame AF1: gen AF_tmp = 1 - F_hormon1/F_all
frame AF1: list tt F_hormon1 F_all AF_tmp if inlist(tt,1,5,10), noobs

mata:
function calcAF(at) {
  // at2 is F(t|unexposed,Z)
  // at1 is F(t,Z)
  return(1 - at[2]/at[1])
}
end



// using the userfunction() option
standsurv, failure timevar(tt) ci frame(AF2, replace) /// 
           at1(.) at2(hormon 1)                       ///
           userfunction(calcAF) userfunctionvar(AF) 
           
// plot the AF 
frame AF2 {
twoway  (rarea AF_lci AF_uci tt, color(%30))    ///
        (line AF tt, pstyle(p1line))            ///
        , legend(off)                           /// 
        ylabel(0(0.05)0.3, format(%4.2f))       ///
        ytitle("AF")                            ///
        xtitle("Years from surgery")            ///
        note("Graph code in ${dofile}",         ///
              size(vsmall) span color(gs3%50))        
}          
