// This code demonstrates winsorizing
// Paul Lambert 2024-09-07

// Load Data
clear all
set scheme fpsaus_c
global dofile stpm3_winsorizing.do

use breast_NW 
stset survtime, failure(dead==1) exit(time 5)

// show centile
centile agediag, c(2 98) 

// model without winsorizing
stpm3 @ns(agediag,df(3)), scale(lncumhazard) df(5) neq(1) nolog
estimates store standard

// model with winsorizing
stpm3 @ns(agediag,df(3) winsor(2 98)), scale(lncumhazard) df(5) neq(1) nolog
estimates store winsorized
            text("winsor(2 98)")
            
// calculate hazard ratios
frame create agehr
frame agehr {
  range agediag 18 99 82
  
  gen t1 = 1
  estimates restore standard
  predict , hazard ci merge timevar(t1) nogen           ///
            at1(agediag 60) at2(.)                      ///
            contrast(ratio) contrastvar(hr_standard) 

  estimates restore winsorized
  predict , hazard ci merge timevar(t1) nogen           ///
            at1(agediag 60) at2(.)                      ///
            contrast(ratio) contrastvar(hr_winsor)             
}

// plot hazard ratios
twoway hist agediag, yaxis(2)  yscale(range(0 0.2) axis(2) off) legend(pos(12)) ///
note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
frame agehr {
  local w1 = word("`e(ef_agediag_winsor1)'",1)
  local w2 = word("`e(ef_agediag_winsor1)'",2)
  addplot: (rarea hr_standard_lci hr_standard_uci agediag, pstyle(p1line) color(%30)) ///
         (line hr_standard agediag, pstyle(p1line))                                   ///
         (line hr_winsor* agediag, pstyle(p2line..) lpattern(solid dash dash))        ///
         , legend(off)                                                                ///
         xline(`w1' , lpattern(-) lcolor(gs7))                                        ///         
         xline(`w2' , lpattern(-) lcolor(gs7))                                        ///         
         yscale(log range(0.5 10))                                                    ///
         ylabel(0.5 1 2 5 10)                                                         ///
         xtitle("Age at diagnosis (years)")                                           ///
         ytitle("Hazard ratio")            norescaling                                ///
         legend(order(2 "Standard" 2 "Winsorized"))
}  


// Example of using from()
stpm3 @ns(agediag,df(3)), scale(lncumhazard) df(5) 
matrix initb = e(b)

stpm3 @ns(agediag,df(3)), scale(lncumhazard) df(5)  from(initb)  ///
                          tvc(@ns(agediag,df(3))) dftvc(3) 



